==> openigtlink_1.11.0.orig.tar.gz: openigtlink-1.11.0/Testing/igtlutil/igtl_test_data_lbmeta.h <==
/*=========================================================================

  Program:   OpenIGTLLink Library -- Dummy lbmeta data
  Module:    $RCSfile: $
  Language:  C
  Date:      $Date: $
  Version:   $Revision: $

  Copyright (c) Insight Software Consortium. All rights reserved.

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notices for more information.

=========================================================================*/

#ifndef __IGTL_TEST_DATA_LBMETA_H
#define __IGTL_TEST_DATA_LBMETA_H

char test_lbmeta_message[] = {
  /*------- OpenIGTLink message header --------*/
  0x00, 0x01,                                     /* Version number */
  0x4c, 0x42, 0x4d, 0x45, 0x54, 0x41, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* LBMETA */
  0x44, 0x65, 0x76, 0x69, 0x63, 0x65, 0x4e, 0x61,
  0x6d, 0x65, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Device name */
  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd2, /* Time stamp */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x5c, /* Body size */
  0x1a, 0x5b, 0x87, 0xbb, 0x24, 0x8d, 0x80, 0x07, /* CRC */

  /*---------- LBMETA message body ------------*/
  /* Image meta data 0 */
  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Image name (device name) */

  0x01,                                           /* Label */
  0x00,                                           /* Reserved */
  0xff, 0x00, 0x00, 0xff,                         /* RGBA */
  0x01, 0x00, 0x00, 0x80, 0x00, 0x20,             /* Size */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 1 */
  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x31, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Image name (device name) */

  0x02,                                           /* Label */
  0x00,                                           /* Reserved */
  0x00, 0xff, 0x00, 0xff,                         /* RGBA */
  0x01, 0x00, 0x00, 0x80, 0x00, 0x20,             /* Size */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 2 */
  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x32, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Image name (device name) */

  0x03,                                           /* Label */
  0x00,                                           /* Reserved */
  0x00, 0x00, 0xff, 0xff,                         /* RGBA */
  0x01, 0x00, 0x00, 0x80, 0x00, 0x20,             /* Size */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */



};

#endif /* IGTL_TEST_DATA_LBMETA_H */

==> openigtlink_3.0.0.orig.tar.gz: openigtlink-3.0.0/Testing/igtlutil/igtl_test_data_lbmeta.h <==
/*=========================================================================

  Program:   OpenIGTLLink Library -- Dummy lbmeta data
  Module:    $RCSfile: $
  Language:  C
  Date:      $Date: $
  Version:   $Revision: $

  Copyright (c) Insight Software Consortium. All rights reserved.

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notices for more information.

=========================================================================*/

#ifndef __IGTL_TEST_DATA_LBMETA_H
#define __IGTL_TEST_DATA_LBMETA_H

unsigned char test_lbmeta_message[] = {
  /*------- OpenIGTLink message header --------*/
  0x00, 0x01,                                     /* Version number */
  0x4c, 0x42, 0x4d, 0x45, 0x54, 0x41, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* LBMETA */
  0x44, 0x65, 0x76, 0x69, 0x63, 0x65, 0x4e, 0x61,
  0x6d, 0x65, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Device name */
  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd4, /* Time stamp */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x5c, /* Body size */
  0x1a, 0x5b, 0x87, 0xbb, 0x24, 0x8d, 0x80, 0x07, /* CRC */

  /*---------- LBMETA message body ------------*/
  /* Image meta data 0 */
  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Image name (device name) */

  0x01,                                           /* Label */
  0x00,                                           /* Reserved */
  0xff, 0x00, 0x00, 0xff,                         /* RGBA */
  0x01, 0x00, 0x00, 0x80, 0x00, 0x20,             /* Size */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 1 */
  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x31, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Image name (device name) */

  0x02,                                           /* Label */
  0x00,                                           /* Reserved */
  0x00, 0xff, 0x00, 0xff,                         /* RGBA */
  0x01, 0x00, 0x00, 0x80, 0x00, 0x20,             /* Size */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 2 */
  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x41, 0x42, 0x45, 0x4c, 0x5f, 0x32, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Image name (device name) */

  0x03,                                           /* Label */
  0x00,                                           /* Reserved */
  0x00, 0x00, 0xff, 0xff,                         /* RGBA */
  0x01, 0x00, 0x00, 0x80, 0x00, 0x20,             /* Size */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */



};

#endif /* IGTL_TEST_DATA_LBMETA_H */
